@@ -1,12 +1,12 @@
 package WWW::Google::Contacts::Type::Organization;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Organization::VERSION = '0.31';
+    $WWW::Google::Contacts::Type::Organization::VERSION = '0.32';
 }
 
 use Moose;
 use MooseX::Types::Moose qw( Str );
-use WWW::Google::Contacts::InternalTypes qw( Rel XmlBool );
+use WWW::Google::Contacts::InternalTypes qw( Rel XmlBool Where );
 use WWW::Google::Contacts::Meta::Attribute::Trait::XmlField;
 
 extends 'WWW::Google::Contacts::Type::Base';
@@ -74,12 +74,13 @@ has primary => (
 );
 
 has where => (
-    isa        => Str,
+    isa        => Where,
     is         => 'rw',
     traits     => ['XmlField'],
     xml_key    => 'gd:where',
     predicate  => 'has_where',
     is_element => 1,
+    coerce     => 1,
 );
 
 no Moose;
